<!-- markdownlint-disable -->

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/tagdata.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `tagdata`




**Global Variables**
---------------
- **tag_data**

---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/tagdata.py#L13"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `get_feature_list`

```python
get_feature_list(primary_name)
```






---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/tagdata.py#L16"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `get_primary_list`

```python
get_primary_list()
```






---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/tagdata.py#L19"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `load_tag_data`

```python
load_tag_data()
```






---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/tagdata.py#L33"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `get_popular_features`

```python
get_popular_features(primary_name)
```






